# Dikkat lütfen

Yeni bir öge oluşturulurken bir uyarı tetiklendi.

- Bu daha önceki OpenSesame sürümleri için hazırlanmış olan bir eklenti kullandığınıza işaret edebilir.
- Uyarılar hata raporunu tetikleyebilir ("Haydaaa, yine yaptım ..."); hata raporunu `bug_report`eklentisini kapatarak devre dışı bırakabilirsiniz.
- Detaylı uyarı mesajını hata ayıklama penceresinde bulabilirsiniz.
